create_epidata_field_info: Add metadata to an epidata_field

View source: R/model.R

create_epidata_field_infoR Documentation

Add metadata to an epidata_field

Description

This function annotates the type of the returned API field. This is used by parse_value downstream to determine how to convert the returned data.

Usage

create_epidata_field_info(name, type, description = "", categories = c())

Arguments

name

The name of the field.

type

The type of the field ("text", "int", "float", etc.).

description

A description of the field's content.

categories

Categories for the field, if applicable.


epidatr documentation built on June 3, 2026, 1:06 a.m.