dot-aux_key_columns: Fetch the declared aux key columns for a source from the...

.aux_key_columnsR Documentation

Fetch the declared aux key columns for a source from the cast-API ⁠metadata/aux_schema/⁠ endpoint.

Description

Fetch the declared aux key columns for a source from the cast-API ⁠metadata/aux_schema/⁠ endpoint.

Usage

.aux_key_columns(source, fetch_args)

epidatr documentation built on Sept. 21, 2026, 5:08 p.m.