| epidata_aux | R Documentation |
Fetch auxiliary data associated with a cast signal.
You can pass a source string to fetch the auxiliary data directly. Alternatively,
you can pass the output of epidata_snapshot() or epidata_archive(). In this
case, epidata_aux automatically retrieves the source from the object, fetches
the matching auxiliary data, and performs a version-aware left join onto the base data.
For the auxiliary key columns and their allowed values, see the source's API docs, e.g. NWSS: https://cmu-delphi.github.io/delphi-epidata/api/v5-signals/nwss.html.
epidata_aux(source, ...)
## Default S3 method:
epidata_aux(
source,
...,
reference_time = "*",
time_values = lifecycle::deprecated(),
snapshot_date = NULL,
report_time = "*",
issues = lifecycle::deprecated(),
columns = NULL,
fetch_args = fetch_args_list()
)
## S3 method for class 'data.frame'
epidata_aux(source, ..., columns = NULL, fetch_args = fetch_args_list())
source |
A source string to retrieve auxiliary data directly, or a tibble returned by
|
... |
Named filters on the auxiliary key columns, such as
|
reference_time |
|
time_values |
|
snapshot_date |
Date, |
report_time |
String or |
issues |
|
columns |
A character vector of columns to return. By default, all columns are returned. |
fetch_args |
|
A tibble::tibble.
epidata_snapshot(), epidata_archive(), epidata_meta()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.