| epidata_meta | R Documentation |
epidata_meta returns source-level metadata from the cast-API,
including report_time ranges, reference_time ranges, and lists of
available signals and geo types.
epidata_meta(source = NULL, fetch_args = fetch_args_list())
source |
string. The data source to query. If |
fetch_args |
|
list. If source is NULL, a named list of source metadata objects.
If source is specified, the metadata list for that source.
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
epidata_snapshot(), epidata_archive(), epidata(), epirange()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.