| pub_covidcast_meta | R Documentation |
This is a V4 endpoint. Starting in October 2026, it is tentatively
deprecated in favor of the V5 API. The new API can be accessed via the
epidata_snapshot(), epidata_archive(), and epidata_meta() functions.
For more details on the changes, refer to vignette("migration-guide"),
and visit the V5 signals documentation
to see which sources are currently available.
API docs: https://cmu-delphi.github.io/delphi-epidata/api/covidcast_meta.html.
Fetch a summary of metadata for all sources and signals that are available in the API, along with basic summary statistics such as the dates they are available, the geographic levels at which they are reported, and etc.
The result can be filtered server-side by passing signals, time_type,
and/or geo_type. Omitted filters (the default) return metadata for
everything.
pub_covidcast_meta(
signals = NULL,
time_type = NULL,
geo_type = NULL,
fetch_args = fetch_args_list()
)
signals |
character. Optionally, the signals to return metadata for,
each formatted as |
time_type |
string. The temporal resolution of the data (either "day" or "week", depending on signal). |
geo_type |
string. Optionally, a single geographic resolution to return metadata for (see: https://cmu-delphi.github.io/delphi-epidata/api/covidcast_geography.html). Defaults to all geographic resolutions. |
fetch_args |
|
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
pub_covidcast(),covidcast_epidata()
pub_covidcast_meta()
# All signals from the Facebook survey data source
pub_covidcast_meta(
signals = "fb-survey:*"
)
# All signals with time_type "day".
pub_covidcast_meta(
time_type = "day",
)
# All signals with geo_type "state".
pub_covidcast_meta(
geo_type = "state",
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.