pub_delphi: Delphi's ILINet outpatient doctor visits forecasts

View source: R/endpoints.R

pub_delphiR Documentation

Delphi's ILINet outpatient doctor visits forecasts

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/delphi.html

Usage

pub_delphi(system, epiweek, fetch_args = fetch_args_list())

Arguments

system

character. System name to fetch. See the available forecasting systems # nolint for details.

epiweek

timeset. Epiweek to fetch. Does not support multiple dates. Make separate calls to fetch data for multiple epiweeks.

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

list

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples



pub_delphi(system = "ec", epiweek = 201501)


epidatr documentation built on June 3, 2026, 1:06 a.m.