pub_dengue_nowcast: Delphi's PAHO dengue nowcasts (North and South America)

View source: R/endpoints.R

pub_dengue_nowcastR Documentation

Delphi's PAHO dengue nowcasts (North and South America)

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/dengue_nowcast.html

Usage

pub_dengue_nowcast(locations, epiweeks = "*", fetch_args = fetch_args_list())

Arguments

locations

character. List of locations to fetch. See the codes for countries and territories in the Americas. # nolint

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples



pub_dengue_nowcast(
  locations = "pr",
  epiweeks = epirange(201401, 202301)
)


epidatr documentation built on June 3, 2026, 1:06 a.m.