| pub_ecdc_ili | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/ecdc_ili.html.
Obtain information on influenza-like-illness from the European Centre for Disease Prevention and Control.
pub_ecdc_ili(
regions,
epiweeks = "*",
...,
issues = NULL,
lag = NULL,
fetch_args = fetch_args_list()
)
regions |
character. List of regions to fetch. See the codes for European countries. # nolint |
epiweeks |
|
... |
not used for values, forces later arguments to bind by name |
issues |
|
lag |
integer. Optionally, the lag of the issues to fetch. See the "Data Versioning" section for details. |
fetch_args |
|
The list of location argument can be found in https://github.com/cmu-delphi/delphi-epidata/blob/main/labels/ecdc_regions.txt.
tibble::tibble
Several endpoints support retrieving historical versions of the data. The following parameters control this and are mutually exclusive (only one can be provided at a time).
as_of: (Date) Retrieve the data as it was on this date.
issues: timeset Retrieve data from a
specific issue date or range of dates.
lag: (integer) Retrieve data with a specific lag from
its issue date.
If none of these is specified, the most recent version of the data is returned.
See vignette("versioned-data") for details and more ways to specify
versioned data.
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
pub_ecdc_ili(regions = "austria", epiweeks = epirange(201901, 202001))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.