pub_meta: Metadata for the Delphi Epidata API

View source: R/endpoints.R

pub_metaR Documentation

Metadata for the Delphi Epidata API

Description

This is a V4 endpoint. Starting in October 2026, it is tentatively deprecated in favor of the V5 API. The new API can be accessed via the epidata_snapshot(), epidata_archive(), and epidata_meta() functions. For more details on the changes, refer to vignette("migration-guide"), and visit the V5 signals documentation to see which sources are currently available.

API docs: https://cmu-delphi.github.io/delphi-epidata/api/meta.html

Usage

pub_meta(fetch_args = fetch_args_list())

Arguments

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

list

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").


epidatr documentation built on Sept. 21, 2026, 5:08 p.m.