pub_nidss_dengue: NIDSS dengue cases (Taiwan)

View source: R/endpoints.R

pub_nidss_dengueR Documentation

NIDSS dengue cases (Taiwan)

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/nidss_dengue.html

Obtains counts of confirmed dengue cases in Taiwan from Taiwan National Infectious Disease Statistical System.

Usage

pub_nidss_dengue(locations, epiweeks = "*", fetch_args = fetch_args_list())

Arguments

locations

character. List of locations to fetch. See Taiwan's geographic codes for details.

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Details

Possible location inputs can be found in https://github.com/cmu-delphi/delphi-epidata/blob/main/labels/nidss_regions.txt and https://github.com/cmu-delphi/delphi-epidata/blob/main/labels/nidss_locations.txt.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples



pub_nidss_dengue(locations = "taipei", epiweeks = epirange(201201, 201301))


epidatr documentation built on June 3, 2026, 1:06 a.m.