pub_nowcast: Delphi's ILI Nearby nowcasts

View source: R/endpoints.R

pub_nowcastR Documentation

Delphi's ILI Nearby nowcasts

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/nowcast.html.

Obtains information on outpatient inluenza-like-illness (ILI) from Delphi's

Usage

pub_nowcast(locations, epiweeks = "*", fetch_args = fetch_args_list())

Arguments

locations

character. List of locations to fetch.

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Details

The full list of location inputs can be accessed at https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#us-regions-and-states and https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#fluview-cities.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples



pub_nowcast(locations = "ca", epiweeks = epirange(201201, 201301))


epidatr documentation built on June 3, 2026, 1:06 a.m.