pvt_cdc: CDC total and by topic webpage visits

View source: R/endpoints.R

pvt_cdcR Documentation

CDC total and by topic webpage visits

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/cdc.html

Usage

pvt_cdc(auth, locations, epiweeks = "*", fetch_args = fetch_args_list())

Arguments

auth

string. Your restricted access key (not the same as API key).

locations

character. List of locations to fetch. See US Regions and States codes # nolint for details.

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples

## Not run: 
pvt_cdc(
  auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
  locations = "fl,ca",
  epirange(201501, 201601)
)

## End(Not run)


epidatr documentation built on June 3, 2026, 1:06 a.m.