pvt_dengue_sensors: PAHO dengue digital surveillance sensors (North and South...

View source: R/endpoints.R

pvt_dengue_sensorsR Documentation

PAHO dengue digital surveillance sensors (North and South America)

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/dengue_sensors.html

Usage

pvt_dengue_sensors(
  auth,
  names,
  locations,
  epiweeks = "*",
  fetch_args = fetch_args_list()
)

Arguments

auth

string. Your restricted access key (not the same as API key).

names

character. List of sensor names to fetch. See the available sensors.

locations

character. List of locations to fetch. See the codes for countries and territories in the Americas. # nolint

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples

## Not run: 
pvt_dengue_sensors(
  auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
  names = "ght",
  locations = "ag",
  epiweeks = epirange(201501, 202001)
)

## End(Not run)


epidatr documentation built on June 3, 2026, 1:06 a.m.