pvt_ght: Google Health Trends health topics search volume

View source: R/endpoints.R

pvt_ghtR Documentation

Google Health Trends health topics search volume

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/ght.html

Estimate of influenza activity based on volume of certain search queries. …

Usage

pvt_ght(auth, locations, epiweeks = "*", query, fetch_args = fetch_args_list())

Arguments

auth

string. Your restricted access key (not the same as API key).

locations

character. List of locations to fetch. See geographic codes # nolint for details.

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

query

string. The query to be fetched.

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples

## Not run: 
pvt_ght(
  auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
  locations = "ma",
  epiweeks = epirange(199301, 202304),
  query = "how to get over the flu"
)

## End(Not run)


epidatr documentation built on June 3, 2026, 1:06 a.m.