pvt_norostat: CDC NoroSTAT norovirus outbreaks

View source: R/endpoints.R

pvt_norostatR Documentation

CDC NoroSTAT norovirus outbreaks

Description

This is point data only, and does not include minima or maxima.

API docs: https://cmu-delphi.github.io/delphi-epidata/api/norostat.html

This is the documentation of the API for accessing the NoroSTAT endpoint of the Delphi’s epidemiological data.

Usage

pvt_norostat(auth, locations, epiweeks = "*", fetch_args = fetch_args_list())

Arguments

auth

string. Your restricted access key (not the same as API key).

locations

character. Locations to fetch. Only a specific list of full state names are permitted. See the locations column in the output of pvt_meta_norostat() for the allowed values.

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples

## Not run: 
pvt_norostat(
  auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
  locations = "Minnesota, Ohio, Oregon, Tennessee, and Wisconsin",
  epiweeks = 201233
)

## End(Not run)


epidatr documentation built on June 3, 2026, 1:06 a.m.