Skip to contents

This is a V4 endpoint. Starting in October 2026, it is tentatively deprecated in favor of the V5 API. The new API can be accessed via the epidata_snapshot(), epidata_archive(), and epidata_meta() functions. For more details on the changes, refer to vignette("migration-guide"), and visit the V5 signals documentation to see which sources are currently available.

API docs: https://cmu-delphi.github.io/delphi-epidata/api/quidel.html

Data provided by Quidel Corp., which contains flu lab test results.

Usage

pvt_quidel(auth, locations, epiweeks = "*", fetch_args = fetch_args_list())

Arguments

auth

string. Your restricted access key (not the same as API key).

locations

character. List of locations to fetch. See HHS regions' codes for details.

epiweeks

timeset. Epiweeks to fetch. Supports epirange() and defaults to all ("*") dates. Format as epirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples

if (FALSE) { # \dontrun{
pvt_quidel(
  auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
  epiweeks = epirange(201201, 202001),
  locations = "hhs1"
)
} # }