| pvt_sensors | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/sensors.html
This is the documentation of the API for accessing the Digital Surveillance Sensors endpoint of the Delphi’s epidemiological. Note: this repository was built to support modeling and forecasting efforts surrounding seasonal influenza (and dengue). In the current COVID-19 pandemic, syndromic surveillance data, like ILI data (influenza-like illness) through FluView, will likely prove very useful. However, we urge caution to users examining the digital surveillance sensors, like ILI Nearby, Google Flu Trends, etc., during the COVID-19 pandemic, because these were designed to track ILI as driven by seasonal influenza, and were NOT designed to track ILI during the COVID-19 pandemic.
pvt_sensors(
auth,
names,
locations,
epiweeks = "*",
fetch_args = fetch_args_list()
)
auth |
string. Your restricted access key (not the same as API key). |
names |
character. List of sensor names to fetch. See the data sources available for details. |
locations |
character. List of locations to fetch. See the codes of the US regions and states # nolint for details. |
epiweeks |
|
fetch_args |
|
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
## Not run:
pvt_sensors(
auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
names = "sar3",
locations = "nat",
epiweeks = epirange(201501, 202001)
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.