pvt_twitter: HealthTweets total and influenza-related tweets

View source: R/endpoints.R

pvt_twitterR Documentation

HealthTweets total and influenza-related tweets

Description

API docs: https://cmu-delphi.github.io/delphi-epidata/api/twitter.html

This is the API documentation for accessing the Twitter Stream endpoint of Delphi’s epidemiological data. Sourced from Healthtweets

Usage

pvt_twitter(
  auth,
  locations,
  ...,
  time_type = c("day", "week"),
  time_values = "*",
  fetch_args = fetch_args_list()
)

Arguments

auth

string. Your restricted access key (not the same as API key).

locations

character. List of locations to fetch. See the codes of the US regions and states # nolint for details.

...

not used for values, forces later arguments to bind by name

time_type

string. The temporal resolution of the data (either "day" or "week", depending on signal).

time_values

timeset. Dates or epiweeks to fetch. Supports epirange() and defaults to all ("*") dates.

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

Value

tibble::tibble

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

Examples

## Not run: 
pvt_twitter(
  auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
  locations = "CA",
  time_type = "week",
  time_values = epirange(201501, 202001)
)

## End(Not run)


epidatr documentation built on June 3, 2026, 1:06 a.m.