warn_v4_sunset: Warn that a V4 endpoint is being phased out in favor of the...

View source: R/utils.R

warn_v4_sunsetR Documentation

Warn that a V4 endpoint is being phased out in favor of the V5 API

Description

Warn that a V4 endpoint is being phased out in favor of the V5 API

Usage

warn_v4_sunset(fn_name)

Arguments

fn_name

string. Name of the calling function, used to throttle the warning and to point users at the right place in the migration guide.


epidatr documentation built on Sept. 21, 2026, 5:08 p.m.