| create_epidata_field_info | R Documentation |
This function annotates the type of the returned API field. This is used
by parse_value downstream to determine how to convert the returned data.
create_epidata_field_info(name, type, description = "", categories = c())
name |
The name of the field. |
type |
The type of the field ("text", "int", "float", etc.). |
description |
A description of the field's content. |
categories |
Categories for the field, if applicable. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.