| .epidatr_shared_params | R Documentation |
This is a central text for parameter documentation
auth |
string. Your restricted access key (not the same as API key). |
locations |
character. List of locations to fetch. |
states |
character. List of states to fetch, formatted as two letter state abbreviations. |
regions |
character. List of regions to fetch. |
epiweeks |
|
time_type |
string. The temporal resolution of the data (either "day" or "week", depending on signal). |
names |
character. Sensor names to fetch. |
dates |
|
time_values |
|
as_of |
Date. Optionally, the as-of date for the issues to fetch. See the "Data Versioning" section for details. |
issues |
|
lag |
integer. Optionally, the lag of the issues to fetch. See the "Data Versioning" section for details. |
fetch_args |
|
... |
not used for values, forces later arguments to bind by name |
Several endpoints support retrieving historical versions of the data. The following parameters control this and are mutually exclusive (only one can be provided at a time).
as_of: (Date) Retrieve the data as it was on this date.
issues: timeset Retrieve data from a
specific issue date or range of dates.
lag: (integer) Retrieve data with a specific lag from
its issue date.
If none of these is specified, the most recent version of the data is returned.
See vignette("versioned-data") for details and more ways to specify
versioned data.
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.