| create_epidata_call | R Documentation |
epidata_call objects are generated internally by endpoint functions like
pub_covidcast; by default, they are piped directly into the fetch
function to fetch and format the data. For most endpoints this will return
a tibble, but a few non-COVIDCAST endpoints will return a JSON-like list
instead.
create_epidata_call(
endpoint,
params,
meta = NULL,
api_version = c("classic", "cast"),
response_format = c("classic", "json", "csv")
)
fetch(epidata_call, fetch_args = fetch_args_list())
endpoint |
the epidata endpoint to call |
params |
the parameters to pass to the epidata endpoint |
meta |
meta data to attach to the epidata call |
api_version |
string. The API version to use. One of "classic" or "cast". |
response_format |
string. The expected format of the response. One of "classic", "json", or "csv". |
epidata_call |
an instance of |
fetch_args |
a |
create_epidata_call is the constructor for epidata_call objects, but you
should not need to use it directly; instead, use an endpoint function,
e.g., pub_covidcast, to generate an epidata_call for the data of
interest.
For create_epidata_call: an epidata_call object
For fetch: a tibble
library(magrittr)
call <- pub_covidcast(
source = "jhu-csse",
signals = "confirmed_7dav_incidence_prop",
time_type = "day",
geo_type = "state",
time_values = epirange(20200601, 20200801),
geo_values = c("ca", "fl"),
fetch_args = fetch_args_list(dry_run = TRUE)
)
call %>% fetch()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.