format_list: Helper function to build a list of values and/or ranges

View source: R/check.R

format_listR Documentation

Helper function to build a list of values and/or ranges

Description

Helper function to build a list of values and/or ranges

Usage

format_list(values)

epidatr documentation built on June 3, 2026, 1:06 a.m.