| pub_dengue_nowcast | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/dengue_nowcast.html
pub_dengue_nowcast(locations, epiweeks = "*", fetch_args = fetch_args_list())
locations |
character. List of locations to fetch. See the codes for countries and territories in the Americas. # nolint |
epiweeks |
|
fetch_args |
|
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
pub_dengue_nowcast(
locations = "pr",
epiweeks = epirange(201401, 202301)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.