| pub_fluview_clinical | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/fluview_clinical.html
pub_fluview_clinical(
regions,
epiweeks = "*",
...,
issues = NULL,
lag = NULL,
fetch_args = fetch_args_list()
)
regions |
character. Vector of location IDs to fetch. Can be "nat" for national, "hhs1"–"hhs10" for HHS Regions, "cen1"–"cen9" for census divisions, lowercase two-letter state or territory abbreviations for most states and territories,"jfk" for New York City, or "ny_minus_jfk" for upstate New York. Full list of locations is available here and here. |
epiweeks |
|
... |
not used for values, forces later arguments to bind by name |
issues |
|
lag |
integer. Optionally, the lag of the issues to fetch. See the "Data Versioning" section for details. |
fetch_args |
|
tibble::tibble
Several endpoints support retrieving historical versions of the data. The following parameters control this and are mutually exclusive (only one can be provided at a time).
as_of: (Date) Retrieve the data as it was on this date.
issues: timeset Retrieve data from a
specific issue date or range of dates.
lag: (integer) Retrieve data with a specific lag from
its issue date.
If none of these is specified, the most recent version of the data is returned.
See vignette("versioned-data") for details and more ways to specify
versioned data.
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
pub_fluview_clinical(regions = "nat", epiweeks = epirange(201601, 201701))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.