Skip to contents

This is a V4 endpoint. Starting in October 2026, it is tentatively deprecated in favor of the V5 API. The new API can be accessed via the epidata_snapshot(), epidata_archive(), and epidata_meta() functions. For more details on the changes, refer to vignette("migration-guide"), and visit the V5 signals documentation to see which sources are currently available.

API docs: https://cmu-delphi.github.io/delphi-epidata/api/fluview_meta.html

Usage

pub_fluview_meta(fetch_args = fetch_args_list())

Arguments

fetch_args

fetch_args_list(). Additional arguments to pass to fetch(). See fetch_args_list() for details.

See also

For example queries showing how to discover signals and build calls, see vignette("signal-discovery", package = "epidatr").

See also

Examples


pub_fluview_meta()
#> Warning: `pub_fluview_meta()` uses the V4 Epidata API.
#>  Starting in October 2026, V4 is tentatively deprecated in favor of the V5
#>   API.
#>  See `vignette("migration-guide")` (or
#>   <https://cmu-delphi.github.io/epidatr/articles/migration-guide.html>) for the
#>   V5 endpoints and how to move to them. Old data will remain available for at
#>   least a year, but new ingestion will end.
#> This warning is displayed once every 8 hours.
#> # A tibble: 1 × 3
#>   latest_update latest_issue table_rows
#>   <date>        <date>            <dbl>
#> 1 2026-08-21    2026-08-09      2844081