| pub_gft | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/gft.html
Obtains estimates of inluenza activity based on volume of certain search queries from Google.
pub_gft(locations, epiweeks = "*", fetch_args = fetch_args_list())
locations |
character. List of locations to fetch. |
epiweeks |
|
fetch_args |
|
Google has discontinued Flu Trends and this is now a static endpoint. Possibile input for locations can be found in https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#hhs-regions, https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#us-states, and https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#selected-us-cities.
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
pub_gft(locations = "hhs1", epiweeks = epirange(201201, 202001))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.