Usage
pub_kcdc_ili(
regions,
epiweeks = "*",
...,
issues = NULL,
lag = NULL,
fetch_args = fetch_args_list()
)Arguments
- regions
character. List of regions to fetch. See South Korea's geographic codes # nolint for details.
- epiweeks
timeset. Epiweeks to fetch. Supportsepirange()and defaults to all ("*") dates. Format asepirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).- ...
not used for values, forces later arguments to bind by name
- issues
timeset. Optionally, the issue(s) of the data to fetch. See the "Data Versioning" section for details.- lag
integer. Optionally, the lag of the issues to fetch. See the "Data Versioning" section for details.
- fetch_args
fetch_args_list(). Additional arguments to pass tofetch(). Seefetch_args_list()for details.
Data Versioning
Several endpoints support retrieving historical versions of the data. The following parameters control this and are mutually exclusive (only one can be provided at a time).
as_of: (Date) Retrieve the data as it was on this date.issues:timesetRetrieve data from a specific issue date or range of dates.lag: (integer) Retrieve data with a specific lag from its issue date.
If none of these is specified, the most recent version of the data is returned.
See vignette("versioned-data") for details and more ways to specify
versioned data.
See also
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
Examples
pub_kcdc_ili(regions = "ROK", epiweeks = 200436)
#> `pub_kcdc_ili()` covers a data source that is no longer updated.
#> ℹ Historical data remains available, but no new data is being ingested.
#> ℹ See the "Endpoints kept for historical reference" section of
#> `vignette("migration-guide")` (or
#> <https://cmu-delphi.github.io/epidatr/articles/migration-guide.html#endpoints-kept-for-historical-reference>)
#> for details.
#> This message is displayed once per session.
#> # A tibble: 1 × 6
#> release_date region issue epiweek lag ili
#> <date> <chr> <date> <date> <dbl> <dbl>
#> 1 2020-11-03 ROK 2020-11-01 2004-09-05 843 0.6