| pub_meta | R Documentation |
This is a V4 endpoint. Starting in October 2026, it is tentatively
deprecated in favor of the V5 API. The new API can be accessed via the
epidata_snapshot(), epidata_archive(), and epidata_meta() functions.
For more details on the changes, refer to vignette("migration-guide"),
and visit the V5 signals documentation
to see which sources are currently available.
API docs: https://cmu-delphi.github.io/delphi-epidata/api/meta.html
pub_meta(fetch_args = fetch_args_list())
fetch_args |
|
list
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.