API docs: https://cmu-delphi.github.io/delphi-epidata/api/nowcast.html.
Obtains information on outpatient inluenza-like-illness (ILI) from Delphi's
Usage
pub_nowcast(locations, epiweeks = "*", fetch_args = fetch_args_list())Arguments
- locations
character. List of locations to fetch.
- epiweeks
timeset. Epiweeks to fetch. Supportsepirange()and defaults to all ("*") dates. Format asepirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).- fetch_args
fetch_args_list(). Additional arguments to pass tofetch(). Seefetch_args_list()for details.
Details
The full list of location inputs can be accessed at https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#us-regions-and-states and https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#fluview-cities.
See also
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
Examples
pub_nowcast(locations = "ca", epiweeks = epirange(201201, 201301))
#> `pub_nowcast()` covers a data source that is no longer updated.
#> ℹ Historical data remains available, but no new data is being ingested.
#> ℹ See the "Endpoints kept for historical reference" section of
#> `vignette("migration-guide")` (or
#> <https://cmu-delphi.github.io/epidatr/articles/migration-guide.html#endpoints-kept-for-historical-reference>)
#> for details.
#> This message is displayed once per session.
#> # A tibble: 53 × 4
#> location epiweek value std
#> <chr> <date> <dbl> <dbl>
#> 1 ca 2012-01-01 2.92 0.269
#> 2 ca 2012-01-08 3.63 0.271
#> 3 ca 2012-01-15 3.34 0.277
#> 4 ca 2012-01-22 3.15 0.221
#> 5 ca 2012-01-29 3.58 0.225
#> 6 ca 2012-02-05 3.84 0.229
#> 7 ca 2012-02-12 3.34 0.229
#> 8 ca 2012-02-19 3.37 0.227
#> 9 ca 2012-02-26 3.83 0.234
#> 10 ca 2012-03-04 3.51 0.232
#> # ℹ 43 more rows