| pub_nowcast | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/nowcast.html.
Obtains information on outpatient inluenza-like-illness (ILI) from Delphi's
pub_nowcast(locations, epiweeks = "*", fetch_args = fetch_args_list())
locations |
character. List of locations to fetch. |
epiweeks |
|
fetch_args |
|
The full list of location inputs can be accessed at https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#us-regions-and-states and https://cmu-delphi.github.io/delphi-epidata/api/geographic_codes.html#fluview-cities.
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
pub_nowcast(locations = "ca", epiweeks = epirange(201201, 201301))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.