Usage
pvt_cdc(auth, locations, epiweeks = "*", fetch_args = fetch_args_list())Arguments
- auth
string. Your restricted access key (not the same as API key).
- locations
character. List of locations to fetch. See US Regions and States codes # nolint for details.
- epiweeks
timeset. Epiweeks to fetch. Supportsepirange()and defaults to all ("*") dates. Format asepirange(startweek, endweek), where startweek and endweek are of the form YYYYWW (string or numeric).- fetch_args
fetch_args_list(). Additional arguments to pass tofetch(). Seefetch_args_list()for details.
See also
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
Examples
if (FALSE) { # \dontrun{
pvt_cdc(
auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
locations = "fl,ca",
epirange(201501, 201601)
)
} # }