| pvt_dengue_sensors | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/dengue_sensors.html
pvt_dengue_sensors(
auth,
names,
locations,
epiweeks = "*",
fetch_args = fetch_args_list()
)
auth |
string. Your restricted access key (not the same as API key). |
names |
character. List of sensor names to fetch. See the available sensors. |
locations |
character. List of locations to fetch. See the codes for countries and territories in the Americas. # nolint |
epiweeks |
|
fetch_args |
|
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
## Not run:
pvt_dengue_sensors(
auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
names = "ght",
locations = "ag",
epiweeks = epirange(201501, 202001)
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.