| pvt_norostat | R Documentation |
This is point data only, and does not include minima or maxima.
API docs: https://cmu-delphi.github.io/delphi-epidata/api/norostat.html
This is the documentation of the API for accessing the NoroSTAT endpoint of the Delphi’s epidemiological data.
pvt_norostat(auth, locations, epiweeks = "*", fetch_args = fetch_args_list())
auth |
string. Your restricted access key (not the same as API key). |
locations |
character. Locations to fetch. Only a specific list of
full state names are permitted. See the |
epiweeks |
|
fetch_args |
|
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
## Not run:
pvt_norostat(
auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
locations = "Minnesota, Ohio, Oregon, Tennessee, and Wisconsin",
epiweeks = 201233
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.