| pvt_twitter | R Documentation |
API docs: https://cmu-delphi.github.io/delphi-epidata/api/twitter.html
This is the API documentation for accessing the Twitter Stream endpoint of Delphi’s epidemiological data. Sourced from Healthtweets
pvt_twitter(
auth,
locations,
...,
time_type = c("day", "week"),
time_values = "*",
fetch_args = fetch_args_list()
)
auth |
string. Your restricted access key (not the same as API key). |
locations |
character. List of locations to fetch. See the codes of the US regions and states # nolint for details. |
... |
not used for values, forces later arguments to bind by name |
time_type |
string. The temporal resolution of the data (either "day" or "week", depending on signal). |
time_values |
|
fetch_args |
|
tibble::tibble
For example queries showing how to discover signals and build calls,
see vignette("signal-discovery", package = "epidatr").
## Not run:
pvt_twitter(
auth = Sys.getenv("DELPHI_EPIDATA_KEY"),
locations = "CA",
time_type = "week",
time_values = epirange(201501, 202001)
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.