| warn_v4_sunset | R Documentation |
Warn that a V4 endpoint is being phased out in favor of the V5 API
warn_v4_sunset(fn_name)
fn_name |
string. Name of the calling function, used to throttle the warning and to point users at the right place in the migration guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.